@@ -4,7 +4,7 @@ use 5.005;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 __END__
@@ -28,11 +28,11 @@ Installs WWW::Mechanize and its dependencies
 
 =head1 AUTHOR
 
-Kevin W. Henwood, <Khen1950fx@aol.com>
+Kevin W. Henwood, <Khen1950fx@yahoo.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 by Kevin W. Henwood
+Copyright (C) 2014 by Kevin W. Henwood
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.005, or at your option, any later version of Perl 5 you may have available.
